@@ -3,8 +3,37 @@ from peewee import Model
 from .database import mysql_db, mysql_db_suivi_prod
 
 
+class SqlViewException(Exception):
+    def __init__(self, message):
+        self.message = message
+
+
 class BaseModel(Model):
     """A base model that will use our MySQL database"""
+
+    @staticmethod
+    def is_sql_view():
+        return False
+
+    class Meta:
+        database = mysql_db
+        table_settings = ['ENGINE=MyISAM', 'DEFAULT CHARSET=utf8']
+
+
+class BaseModelSqlView(Model):
+    """A base model that will use our MySQL database"""
+
+    @staticmethod
+    def is_sql_view():
+        return True
+
+    def save(self):
+        """insert or update are not allowed in SQL view"""
+        raise SqlViewException('Insert or update not allowed in SQL view model')
+
+    def create_view(self):
+        raise SqlViewException('Need inherit to create the view')
+
     class Meta:
         database = mysql_db
         table_settings = ['ENGINE=MyISAM', 'DEFAULT CHARSET=utf8']
@@ -12,6 +41,11 @@ class BaseModel(Model):
 
 class BaseModelSuiviProd(Model):
     """A base model that will use our MySQL database"""
+
+    @staticmethod
+    def is_sql_view():
+        return False
+
     class Meta:
         database = mysql_db_suivi_prod
         table_settings = ['ENGINE=MyISAM', 'DEFAULT CHARSET=utf8']
