@@ -1,6 +1,7 @@
 # flake8: noqa
 from .config import Config
-from .users import User, Profil
+from .users import User, Profil, Rights
+from .poste import Poste
 from .products import Product, Seuil, LotRetire, TopFive
 from .ucd import Ucd
 from .cip import Cip
@@ -8,14 +9,12 @@ from .labels import Label
 
 from .patient import (Patient, Patient_Histo)
 from .sejour import Sejour
-from .service import Service
+from .service import Service, Endpoint
 from .prescription import Prescription, PrescriptionItem
 from .dispensation import Dispensation, DispensationItem, FListe, FItem, FListeError
-from .emplacements import Emplacements
-
 
 from .magasin import Magasin, Adresse, Compteur, Espace, MagasinService, Zone, ZoneMag
-from .stock import Stock
+from .stock import Stock, CodeBlocage
 from .gpao import Gpao
 from .historique import (
     Historique,
@@ -29,7 +28,9 @@ from .historique import (
     HistoriqueSachet,
 )
 from .log import LogAstus, MessageAstus
-
 from .menu import Web_Menu, Web_Menu_i18n
-
 from .suivi_production import SuiviProd
+
+from .webview_emplacements import Emplacements, WebviewEmplacement
+from .webview_patient import WebviewPatientHisto
+from .webview_taquin import WebviewTaquin, WebviewDemiTaquin
